"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.KeyboardAvoidingInput = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _style = _interopRequireDefault(require("./style"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const KeyboardAvoidingInput = /*#__PURE__*/(0, _react.forwardRef)((props, ref) => {
  const {
    value,
    style,
    onBlur,
    onFocus,
    keyboardType,
    onChangeText,
    secureTextEntry,
    onSubmitEditing,
    returnKeyType,
    returnKeyLabel,
    input: Input,
    returnKeyIcon,
    showPasswordIcon,
    hidePasswordIcon,
    inputStyle,
    containerStyle,
    toggleShowText = 'Show',
    toggleHideText = 'Hide',
    toggleVisibilityPassword = false,
    returnKeyTypeClear = false,
    onOpen,
    onClose,
    androidOpenInputDelay = 200,
    actionLabelStyle,
    actionContainerStyle,
    ...rest
  } = props;

  const inputRef = _react.default.useRef(null);

  const isIOS = (0, _utils.isIOSDevice)();
  const keyBoardTypeHelperIos = (0, _utils.keyBoardTypeHelperForIos)(keyboardType, secureTextEntry);
  const [modalVisible, setModalVisible] = (0, _react.useState)(false);
  const [visiblePass, setVisiblePass] = (0, _react.useState)(false);

  const focus = () => openModal();

  const blur = () => closeModal();

  const clear = () => clearInput();

  const toggleVisiblePass = () => setVisiblePass(prev => !prev);

  const openModal = () => {
    if (modalVisible) {
      return;
    }

    setModalVisible(true);
    setTimeout(() => {
      var _inputRef$current;

      inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.focus();
    }, androidOpenInputDelay);
    onOpen === null || onOpen === void 0 ? void 0 : onOpen();
  };

  const closeModal = () => {
    setModalVisible(false);

    if (visiblePass) {
      toggleVisiblePass();
    }

    onClose === null || onClose === void 0 ? void 0 : onClose();
  };

  const _onSubmitEditing = e => {
    closeModal();
    onSubmitEditing === null || onSubmitEditing === void 0 ? void 0 : onSubmitEditing(e);
  };

  const _onBlur = e => {
    closeModal();
    onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
  };

  const _onFocus = e => {
    e.preventDefault();
    openModal();
    onFocus === null || onFocus === void 0 ? void 0 : onFocus(e);
  };

  const clearInput = () => {
    onChangeText === null || onChangeText === void 0 ? void 0 : onChangeText('');
  };

  const renderActionButton = () => {
    if (!secureTextEntry) {
      const iconAction = returnKeyIcon || /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: [_style.default.actionLabel, actionLabelStyle]
      }, returnKeyLabel || returnKeyType);

      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
        style: [_style.default.action, actionContainerStyle],
        onPress: returnKeyTypeClear ? () => clearInput() : () => _onSubmitEditing()
      }, iconAction);
    }

    return null;
  };

  const renderPasswordIcon = () => {
    if (secureTextEntry && toggleVisibilityPassword) {
      const iconHide = hidePasswordIcon || /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: [_style.default.actionLabel, actionLabelStyle]
      }, toggleHideText);

      const iconShow = showPasswordIcon || /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
        style: [_style.default.actionLabel, actionLabelStyle]
      }, toggleShowText);

      return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
        style: [_style.default.action, actionContainerStyle],
        onPress: toggleVisiblePass
      }, visiblePass ? iconHide : iconShow);
    }

    return null;
  };

  (0, _react.useImperativeHandle)(ref, () => ({
    focus,
    blur,
    clear
  }));
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(Input, _extends({}, rest, {
    style: style,
    keyboardType: keyboardType,
    editable: isIOS ? !modalVisible : true,
    secureTextEntry: secureTextEntry,
    onChangeText: onChangeText,
    onPressIn: openModal,
    value: value,
    showSoftInputOnFocus: isIOS,
    onFocus: _onFocus,
    onBlur: _onBlur
  })), /*#__PURE__*/_react.default.createElement(_reactNative.Modal, {
    visible: modalVisible,
    onShow: focus,
    onRequestClose: closeModal,
    transparent: true,
    animationType: "slide"
  }, /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
    style: _style.default.safeArea
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    style: _style.default.outside,
    onPress: closeModal
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [keyBoardTypeHelperIos ? _style.default.wrapperFixKeyboardType : _style.default.wrapper, containerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, _extends({
    ref: inputRef
  }, rest, {
    keyboardType: keyboardType,
    style: [_style.default.input, inputStyle],
    autoFocus: isIOS,
    onFocus: _onFocus,
    onBlur: _onBlur,
    onChangeText: onChangeText,
    onSubmitEditing: _onSubmitEditing,
    secureTextEntry: visiblePass ? false : secureTextEntry,
    value: value
  })), renderActionButton(), renderPasswordIcon()))));
});
exports.KeyboardAvoidingInput = KeyboardAvoidingInput;
//# sourceMappingURL=index.js.map