function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React, { useState, forwardRef, useImperativeHandle } from 'react';
import { Modal, TouchableOpacity, TextInput, SafeAreaView, View, Text } from 'react-native';
import Style from './style';
import { isIOSDevice, keyBoardTypeHelperForIos } from '../utils';
export const KeyboardAvoidingInput = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    value,
    style,
    onBlur,
    onFocus,
    keyboardType,
    onChangeText,
    secureTextEntry,
    onSubmitEditing,
    returnKeyType,
    returnKeyLabel,
    input: Input,
    returnKeyIcon,
    showPasswordIcon,
    hidePasswordIcon,
    inputStyle,
    containerStyle,
    toggleShowText = 'Show',
    toggleHideText = 'Hide',
    toggleVisibilityPassword = false,
    returnKeyTypeClear = false,
    onOpen,
    onClose,
    androidOpenInputDelay = 200,
    actionLabelStyle,
    actionContainerStyle,
    ...rest
  } = props;
  const inputRef = React.useRef(null);
  const isIOS = isIOSDevice();
  const keyBoardTypeHelperIos = keyBoardTypeHelperForIos(keyboardType, secureTextEntry);
  const [modalVisible, setModalVisible] = useState(false);
  const [visiblePass, setVisiblePass] = useState(false);

  const focus = () => openModal();

  const blur = () => closeModal();

  const clear = () => clearInput();

  const toggleVisiblePass = () => setVisiblePass(prev => !prev);

  const openModal = () => {
    if (modalVisible) {
      return;
    }

    setModalVisible(true);
    setTimeout(() => {
      var _inputRef$current;

      inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.focus();
    }, androidOpenInputDelay);
    onOpen === null || onOpen === void 0 ? void 0 : onOpen();
  };

  const closeModal = () => {
    setModalVisible(false);

    if (visiblePass) {
      toggleVisiblePass();
    }

    onClose === null || onClose === void 0 ? void 0 : onClose();
  };

  const _onSubmitEditing = e => {
    closeModal();
    onSubmitEditing === null || onSubmitEditing === void 0 ? void 0 : onSubmitEditing(e);
  };

  const _onBlur = e => {
    closeModal();
    onBlur === null || onBlur === void 0 ? void 0 : onBlur(e);
  };

  const _onFocus = e => {
    e.preventDefault();
    openModal();
    onFocus === null || onFocus === void 0 ? void 0 : onFocus(e);
  };

  const clearInput = () => {
    onChangeText === null || onChangeText === void 0 ? void 0 : onChangeText('');
  };

  const renderActionButton = () => {
    if (!secureTextEntry) {
      const iconAction = returnKeyIcon || /*#__PURE__*/React.createElement(Text, {
        style: [Style.actionLabel, actionLabelStyle]
      }, returnKeyLabel || returnKeyType);
      return /*#__PURE__*/React.createElement(TouchableOpacity, {
        style: [Style.action, actionContainerStyle],
        onPress: returnKeyTypeClear ? () => clearInput() : () => _onSubmitEditing()
      }, iconAction);
    }

    return null;
  };

  const renderPasswordIcon = () => {
    if (secureTextEntry && toggleVisibilityPassword) {
      const iconHide = hidePasswordIcon || /*#__PURE__*/React.createElement(Text, {
        style: [Style.actionLabel, actionLabelStyle]
      }, toggleHideText);
      const iconShow = showPasswordIcon || /*#__PURE__*/React.createElement(Text, {
        style: [Style.actionLabel, actionLabelStyle]
      }, toggleShowText);
      return /*#__PURE__*/React.createElement(TouchableOpacity, {
        style: [Style.action, actionContainerStyle],
        onPress: toggleVisiblePass
      }, visiblePass ? iconHide : iconShow);
    }

    return null;
  };

  useImperativeHandle(ref, () => ({
    focus,
    blur,
    clear
  }));
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Input, _extends({}, rest, {
    style: style,
    keyboardType: keyboardType,
    editable: isIOS ? !modalVisible : true,
    secureTextEntry: secureTextEntry,
    onChangeText: onChangeText,
    onPressIn: openModal,
    value: value,
    showSoftInputOnFocus: isIOS,
    onFocus: _onFocus,
    onBlur: _onBlur
  })), /*#__PURE__*/React.createElement(Modal, {
    visible: modalVisible,
    onShow: focus,
    onRequestClose: closeModal,
    transparent: true,
    animationType: "slide"
  }, /*#__PURE__*/React.createElement(SafeAreaView, {
    style: Style.safeArea
  }, /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: Style.outside,
    onPress: closeModal
  }), /*#__PURE__*/React.createElement(View, {
    style: [keyBoardTypeHelperIos ? Style.wrapperFixKeyboardType : Style.wrapper, containerStyle]
  }, /*#__PURE__*/React.createElement(TextInput, _extends({
    ref: inputRef
  }, rest, {
    keyboardType: keyboardType,
    style: [Style.input, inputStyle],
    autoFocus: isIOS,
    onFocus: _onFocus,
    onBlur: _onBlur,
    onChangeText: onChangeText,
    onSubmitEditing: _onSubmitEditing,
    secureTextEntry: visiblePass ? false : secureTextEntry,
    value: value
  })), renderActionButton(), renderPasswordIcon()))));
});
//# sourceMappingURL=index.js.map